﻿// エクステンション開発で参照するAPIの名前空間の宣言
using NextDesign.Extension;
using NextDesign.Core;
using NextDesign.Desktop;

/// <summary>
/// DLL形式のエクステンション確認用クラス。
/// </summary>
/// <remarks>
/// ・IExtensionインタフェースを実装すること。
/// ・マニフェストに対応した名前のメソッドを定義すること。
/// </remarks>
public class MyExtension : IExtension
{
	/// <summary>
	/// エクステンションのコンテキスト
	/// </summary>
	private IContext m_Context;

	/// <summary>
	/// 拡張機能の処理を実行する
	/// </summary>
	/// <param name="context">コンテキスト</param>
	/// <param name="parameters">パラメータ</param>
	public void Run(ICommandContext context, ICommandParams parameters)
	{
		var project = context.App.Workspace.CurrentProject;
		if (project == null)
		{
			context.App.Window.UI.ShowInformationDialog(
				"プロジェクトファイルを開いてから実行してください。",
				ResourceString("Application.Name") );
			return;
		}

		// TODO
		context.App.Window.UI.ShowInformationDialog(
			"Project Name: " + project.Name,
			ResourceString("Application.Name") );
		var models = project.GetAllChildren();
	}

	/// <summary>
	/// エクステンションを活性化する
	/// </summary>
	/// <param name="context">実行コンテキスト</param>
	public void Activate(IContext context)
	{
		m_Context = context;
	}

	/// <summary>
	/// エクステンションを非活性化する
	/// </summary>
	/// <param name="context">実行コンテキスト</param>
	public void Deactivate(IContext context)
	{
		// Nothing
	}

	/// <summary>
	/// ロケールに応じたメッセージを取得する
	/// </summary>
	/// <param name="key">キー</param>
	/// <returns>メッセージ</returns>
	private string ResourceString(string key)
	{
		return m_Context.GetResourceString(key);
	}
}

#if (!DLL)
public void Run(ICommandContext context, ICommandParams parameters)
{
	var ext = new MyExtension();
	ext.Activate(context);
	ext.Run(context, parameters);
	ext.Deactivate(context);
}
#endif
